==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Information/InfoDistanceEE/ts/InfoDistanceEE_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>InfoDistanceEE</name>
    <message>
        <location filename="../InfoDistanceEE.js" line="+62"/>
        <source>Specify first entity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Specify second entity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translation type="unfinished">完了</translation>
    </message>
    <message>
        <location line="+92"/>
        <source>Distance:</source>
        <translation type="unfinished">距離:</translation>
    </message>
    <message>
        <location filename="../InfoDistanceEEInit.js" line="+2"/>
        <source>Distance &amp;Entity to Entity</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InfoDistanceEP</name>
    <message>
        <source>Specify entity</source>
        <translation type="vanished">エンティティを指定</translation>
    </message>
    <message>
        <source>Specify point</source>
        <translation type="vanished">点を指定</translation>
    </message>
    <message>
        <source>Done</source>
        <translation type="vanished">完了</translation>
    </message>
    <message>
        <source>Distance:</source>
        <translation type="vanished">距離:</translation>
    </message>
    <message>
        <source>Distance &amp;Entity to Point</source>
        <translation type="vanished">&amp;E エンティティと点の距離</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Information/InfoDistanceEE/ts/InfoDistanceEE_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>InfoDistanceEE</name>
    <message>
        <location filename="../InfoDistanceEE.js" line="+62"/>
        <source>Specify first entity</source>
        <translation>最初のエンティティを指定して下さい</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Specify second entity</source>
        <translation>2つ目のエンティティを指定して下さい</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translation>完了</translation>
    </message>
    <message>
        <location line="+92"/>
        <source>Distance:</source>
        <translation>距離:</translation>
    </message>
    <message>
        <location filename="../InfoDistanceEEInit.js" line="+2"/>
        <source>Distance &amp;Entity to Entity</source>
        <translation>エンティティ同士の距離</translation>
    </message>
</context>
<context>
    <name>InfoDistanceEP</name>
    <message>
        <source>Specify entity</source>
        <translation type="vanished">エンティティを指定</translation>
    </message>
    <message>
        <source>Specify point</source>
        <translation type="vanished">点を指定</translation>
    </message>
    <message>
        <source>Done</source>
        <translation type="vanished">完了</translation>
    </message>
    <message>
        <source>Distance:</source>
        <translation type="vanished">距離:</translation>
    </message>
    <message>
        <source>Distance &amp;Entity to Point</source>
        <translation type="vanished">&amp;E エンティティと点の距離</translation>
    </message>
</context>
</TS>
